package com.fs.his.service;

import java.util.List;
import com.fs.his.domain.FsUserAddress;

/**
 * 用户地址Service接口
 *
 * @author fs
 * @date 2023-07-03
 */
public interface IFsUserAddressService
{
    /**
     * 查询用户地址
     *
     * @param addressId 用户地址主键
     * @return 用户地址
     */
    public FsUserAddress selectFsUserAddressByAddressId(Long addressId);

    /**
     * 查询用户地址列表
     *
     * @param fsUserAddress 用户地址
     * @return 用户地址集合
     */
    public List<FsUserAddress> selectFsUserAddressList(FsUserAddress fsUserAddress);

    /**
     * 新增用户地址
     *
     * @param fsUserAddress 用户地址
     * @return 结果
     */
    public int insertFsUserAddress(FsUserAddress fsUserAddress);

    /**
     * 修改用户地址
     *
     * @param fsUserAddress 用户地址
     * @return 结果
     */
    public int updateFsUserAddress(FsUserAddress fsUserAddress);

    /**
     * 批量删除用户地址
     *
     * @param addressIds 需要删除的用户地址主键集合
     * @return 结果
     */
    public int deleteFsUserAddressByAddressIds(Long[] addressIds);

    /**
     * 删除用户地址信息
     *
     * @param addressId 用户地址主键
     * @return 结果
     */
    public int deleteFsUserAddressByAddressId(Long addressId);

    Integer selectFsUserAddressCountsByUserId(long userId);

    int clearIsDefalut(long userId);

    String getKdnAddress(String address);

    FsUserAddress selectFsUserAddressByDefault(long userId);

    Boolean isEntityNull(FsUserAddress fsUserAddress);

    Long selectFsUserAddressListCount(FsUserAddress fsUserAddress);
}
